@@ -6,5 +6,7 @@
     },
     'Model::Baz' => {
         qux => 'xyzzy'
-    }
+    },
+    foo_sub => '__foo(x,y)__',
+    literal_macro => '__literal(__DATA__)__',
 }
